# LOFAR Sun Tools

 Handy scripts and modules for the LOFAR data processing for Solar and Space Weather.
 
 Quick start: [document](https://lofar-sun-tools.readthedocs.io/en/latest/)

 Test data: [https://pjzhang.cc/static/demo_data.7z](https://pjzhang.cc/static/demo_data.7z)